==> quickcapture_react_native-0.0.11.tgz: package/src/index.tsx <==
import { NativeModules, Platform } from 'react-native';

const LINKING_ERROR =
  `The package 'quickcapture' doesn't seem to be linked. Make sure: \n\n` +
  Platform.select({ ios: "- You have run 'pod install'\n", default: '' }) +
  '- You rebuilt the app after installing the package\n' +
  '- You are not using Expo Go\n';

const Quickcapture = NativeModules.Quickcapture
  ? NativeModules.Quickcapture
  : new Proxy(
      {},
      {
        get() {
          throw new Error(LINKING_ERROR);
        },
      }
    );

/**
 * Initializes the Quickcapture module.
 * @returns {boolean} Returns true to indicate successful initialization.
 */
export function init() {
  Quickcapture.initialise();
  return true;
}

/**
 * Captures a document using the device camera.
 * @returns {Promise<string>} A promise that resolves to the path of the captured document image.
 */
export function captureDocument(): Promise<string> {
  return new Promise((resolve, reject) => {
    Quickcapture.startCapture({ saveToGallery: true })
      .then((responseString: string) => {
        console.log(responseString);
        resolve(responseString); // Resolve the outer promise with the image path
      })
      .catch((error: Error) => {
        console.error(error);
        reject(error); // Reject the outer promise with the error
      });
  });
}

/**
 * Builds a PDF from the last captured document.
 * @returns {Promise<string>} A promise that resolves to the file path of the generated PDF.
 */
export function buildPdfForLastDocumentCapture(): Promise<string> {
  return new Promise((resolve, reject) => {
    Quickcapture.buildPdfFileForLastCaptureSet()
      .then((pdfFilePath: string) => {
        console.log(pdfFilePath);
        resolve(pdfFilePath); // Resolve the outer promise with the image path
      })
      .catch((error: Error) => {
        console.error(error);
        reject(error); // Reject the outer promise with the error
      });
  });
}

/**
 * Captures an optical code (QR code or barcode) using the device camera.
 * @returns {Promise<string>} A promise that resolves to the scanned code data.
 */
export function captureOpticalCode(): Promise<string> {
  return new Promise((resolve, reject) => {
    Quickcapture.startOpticalCodeCapture({})
      .then((response: string) => {
        console.log(response);
        resolve(response); // Resolve the outer promise with the image path
      })
      .catch((error: Error) => {
        console.error(error);
        reject(error); // Reject the outer promise with the error
      });
  });
}

/**
 * Generates a QR code from provided data.
 * @param {string} data The data to encode in the QR code.
 * @returns {Promise<string>} A promise that resolves to Base64 data of the generated QR code image.
 */
export function generateQRCode(data: string): Promise<string> {
  return new Promise((resolve, reject) => {
    Quickcapture.generateQRCode(data)
      .then((response: string) => {
        console.log(response);
        resolve(response); // Resolve the outer promise with the image path
      })
      .catch((error: Error) => {
        console.error(error);
        reject(error); // Reject the outer promise with the error
      });
  });
}

/**
 * Generates a barcode from provided data.
 * @param {string} data The data to encode in the barcode.
 * @param {boolean} includeText Optional flag to include text below the barcode.
 * @returns {Promise<string>} A promise that resolves to Base64 data of the generated QR code image.
 */
export function generateBarcode(
  data: string,
  includeText: boolean = false
): Promise<string> {
  return new Promise((resolve, reject) => {
    Quickcapture.generateBarcode(data, includeText)
      .then((response: string) => {
        console.log(response);
        resolve(response); // Resolve the outer promise with the image path
      })
      .catch((error: Error) => {
        console.error(error);
        reject(error); // Reject the outer promise with the error
      });
  });
}

==> quickcapture_react_native-0.0.12.tgz: package/src/index.tsx <==
import { NativeModules, Platform } from 'react-native';

const LINKING_ERROR =
  `The package 'quickcapture' doesn't seem to be linked. Make sure: \n\n` +
  Platform.select({ ios: "- You have run 'pod install'\n", default: '' }) +
  '- You rebuilt the app after installing the package\n' +
  '- You are not using Expo Go\n';

const Quickcapture = NativeModules.Quickcapture
  ? NativeModules.Quickcapture
  : new Proxy(
      {},
      {
        get() {
          throw new Error(LINKING_ERROR);
        },
      }
    );

/**
 * Activate the plugin license.
 * @returns {Promise<string>} A promise that resolves to the path of the captured document image.
 */
export function activateLicense(
  androidLic: string,
  iosLic: string
): Promise<string> {
  return new Promise((resolve, reject) => {
    // Determine which license key to use based on the platform
    const licenseKey = Platform.OS === 'android' ? androidLic : iosLic;

    // Pass the appropriate license key to the native method
    Quickcapture.activateLicense(licenseKey)
      .then((responseString: string) => {
        console.log(responseString);
        resolve(responseString); // Resolve the outer promise with the response string
      })
      .catch((error: Error) => {
        console.error(error);
        reject(error); // Reject the outer promise with the error
      });
  });
}

/**
 * Initializes the Quickcapture module.
 * @returns {boolean} Returns true to indicate successful initialization.
 */
export function initialise() {
  Quickcapture.initialise();
  return true;
}

/**
 * Captures a document using the device camera.
 * @returns {Promise<string>} A promise that resolves to the path of the captured document image.
 */
export function captureDocument(): Promise<string> {
  return new Promise((resolve, reject) => {
    Quickcapture.startCapture({ saveToGallery: true })
      .then((responseString: string) => {
        console.log(responseString);
        resolve(responseString); // Resolve the outer promise with the image path
      })
      .catch((error: Error) => {
        console.error(error);
        reject(error); // Reject the outer promise with the error
      });
  });
}

/**
 * Builds a PDF from the last captured document.
 * @returns {Promise<string>} A promise that resolves to the file path of the generated PDF.
 */
export function buildPdfForLastDocumentCapture(): Promise<string> {
  return new Promise((resolve, reject) => {
    Quickcapture.buildPdfFileForLastCaptureSet()
      .then((pdfFilePath: string) => {
        console.log(pdfFilePath);
        resolve(pdfFilePath); // Resolve the outer promise with the image path
      })
      .catch((error: Error) => {
        console.error(error);
        reject(error); // Reject the outer promise with the error
      });
  });
}

/**
 * Captures an optical code (QR code or barcode) using the device camera.
 * @returns {Promise<string>} A promise that resolves to the scanned code data.
 */
export function captureOpticalCode(): Promise<string> {
  return new Promise((resolve, reject) => {
    Quickcapture.startOpticalCodeCapture({})
      .then((response: string) => {
        console.log(response);
        resolve(response); // Resolve the outer promise with the image path
      })
      .catch((error: Error) => {
        console.error(error);
        reject(error); // Reject the outer promise with the error
      });
  });
}

/**
 * Generates a QR code from provided data.
 * @param {string} data The data to encode in the QR code.
 * @returns {Promise<string>} A promise that resolves to Base64 data of the generated QR code image.
 */
export function generateQRCode(data: string): Promise<string> {
  return new Promise((resolve, reject) => {
    Quickcapture.generateQRCode(data)
      .then((response: string) => {
        console.log(response);
        resolve(response); // Resolve the outer promise with the image path
      })
      .catch((error: Error) => {
        console.error(error);
        reject(error); // Reject the outer promise with the error
      });
  });
}

/**
 * Generates a barcode from provided data.
 * @param {string} data The data to encode in the barcode.
 * @param {boolean} includeText Optional flag to include text below the barcode.
 * @returns {Promise<string>} A promise that resolves to Base64 data of the generated QR code image.
 */
export function generateBarcode(
  data: string,
  includeText: boolean = false
): Promise<string> {
  return new Promise((resolve, reject) => {
    Quickcapture.generateBarcode(data, includeText)
      .then((response: string) => {
        console.log(response);
        resolve(response); // Resolve the outer promise with the image path
      })
      .catch((error: Error) => {
        console.error(error);
        reject(error); // Reject the outer promise with the error
      });
  });
}
